@@ -41,5 +41,9 @@ class Github(Provider):
     def get_raw_file(self, path: str, tag: str):
         return f"{self.source_url}/raw/{tag}/{path}"
 
+    def get_source_file_declaration(self, path: str, tag: str):
+        owner_repo = "/".join(self.source_url.split("/")[-2:])
+        return f'github("{owner_repo}", path="{path}", tag="{tag}")'
+
 
 PROVIDERS = [Github]
